@@ -1,5 +1,6 @@
-/* 
- * Copyright (C) 2003-2006 Jean-Yves Lefort <jylefort@brutele.be>
+/*
+ * Mail Notification
+ * Copyright (C) 2003-2007 Jean-Yves Lefort <jylefort@brutele.be>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -11,9 +12,9 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #ifndef _MN_CONF_H
@@ -23,7 +24,6 @@
 #include <gtk/gtk.h>
 #include <eel/eel.h>
 #include "mn-util.h"
-#include "mn-locked-callback.h"
 
 #define MN_CONF_NAMESPACE \
   "/apps/mail-notification"
@@ -41,6 +41,12 @@
   MN_CONF_COMMANDS_MAIL_READ_NAMESPACE "/enabled"
 #define MN_CONF_COMMANDS_MAIL_READ_COMMAND \
   MN_CONF_COMMANDS_MAIL_READ_NAMESPACE "/command"
+#define MN_CONF_COMMANDS_MAIL_CHANGED_NAMESPACE \
+  MN_CONF_COMMANDS_NAMESPACE "/mail-changed"
+#define MN_CONF_COMMANDS_MAIL_CHANGED_ENABLED \
+  MN_CONF_COMMANDS_MAIL_CHANGED_NAMESPACE "/enabled"
+#define MN_CONF_COMMANDS_MAIL_CHANGED_COMMAND \
+  MN_CONF_COMMANDS_MAIL_CHANGED_NAMESPACE "/command"
 #define MN_CONF_UI_NAMESPACE \
   MN_CONF_NAMESPACE "/ui"
 #define MN_CONF_PROPERTIES_DIALOG \
@@ -51,42 +57,6 @@
   MN_CONF_NAMESPACE "/trusted-x509-certificates"
 #define MN_CONF_TRUSTED_SERVERS \
   MN_CONF_NAMESPACE "/trusted-servers"
-#define MN_CONF_MAIL_SUMMARY_POPUP_NAMESPACE \
-  MN_CONF_NAMESPACE "/mail-summary-popup"
-#define MN_CONF_MAIL_SUMMARY_POPUP_ENABLE \
-  MN_CONF_MAIL_SUMMARY_POPUP_NAMESPACE "/enable"
-#define MN_CONF_MAIL_SUMMARY_POPUP_AUTOCLOSE \
-  MN_CONF_MAIL_SUMMARY_POPUP_NAMESPACE "/autoclose"
-#define MN_CONF_MAIL_SUMMARY_POPUP_AUTOCLOSE_DELAY_NAMESPACE \
-  MN_CONF_MAIL_SUMMARY_POPUP_NAMESPACE "/autoclose-delay"
-#define MN_CONF_MAIL_SUMMARY_POPUP_AUTOCLOSE_DELAY_MINUTES \
-  MN_CONF_MAIL_SUMMARY_POPUP_AUTOCLOSE_DELAY_NAMESPACE "/minutes"
-#define MN_CONF_MAIL_SUMMARY_POPUP_AUTOCLOSE_DELAY_SECONDS \
-  MN_CONF_MAIL_SUMMARY_POPUP_AUTOCLOSE_DELAY_NAMESPACE "/seconds"
-#define MN_CONF_MAIL_SUMMARY_POPUP_LAYOUT \
-  MN_CONF_MAIL_SUMMARY_POPUP_NAMESPACE "/layout"
-#define MN_CONF_MAIL_SUMMARY_POPUP_POSITION \
-  MN_CONF_MAIL_SUMMARY_POPUP_NAMESPACE "/position"
-#define MN_CONF_MAIL_SUMMARY_POPUP_OFFSET_NAMESPACE \
-  MN_CONF_MAIL_SUMMARY_POPUP_NAMESPACE "/offset"
-#define MN_CONF_MAIL_SUMMARY_POPUP_HORIZONTAL_OFFSET \
-  MN_CONF_MAIL_SUMMARY_POPUP_OFFSET_NAMESPACE "/horizontal"
-#define MN_CONF_MAIL_SUMMARY_POPUP_VERTICAL_OFFSET \
-  MN_CONF_MAIL_SUMMARY_POPUP_OFFSET_NAMESPACE "/vertical"
-#define MN_CONF_MAIL_SUMMARY_POPUP_ONLY_RECENT \
-  MN_CONF_MAIL_SUMMARY_POPUP_NAMESPACE "/only-recent"
-#define MN_CONF_MAIL_SUMMARY_POPUP_FONTS_NAMESPACE \
-  MN_CONF_MAIL_SUMMARY_POPUP_NAMESPACE "/fonts"
-#define MN_CONF_MAIL_SUMMARY_POPUP_FONTS_ASPECT_SOURCE \
-  MN_CONF_MAIL_SUMMARY_POPUP_FONTS_NAMESPACE "/aspect-source"
-#define MN_CONF_MAIL_SUMMARY_POPUP_FONTS_TITLE_NAMESPACE \
-  MN_CONF_MAIL_SUMMARY_POPUP_FONTS_NAMESPACE "/title"
-#define MN_CONF_MAIL_SUMMARY_POPUP_FONTS_TITLE_FONT \
-  MN_CONF_MAIL_SUMMARY_POPUP_FONTS_TITLE_NAMESPACE "/font"
-#define MN_CONF_MAIL_SUMMARY_POPUP_FONTS_CONTENTS_NAMESPACE \
-  MN_CONF_MAIL_SUMMARY_POPUP_FONTS_NAMESPACE "/contents"
-#define MN_CONF_MAIL_SUMMARY_POPUP_FONTS_CONTENTS_FONT \
-  MN_CONF_MAIL_SUMMARY_POPUP_FONTS_CONTENTS_NAMESPACE "/font"
 #define MN_CONF_DISPLAY_SEEN_MAIL \
   MN_CONF_NAMESPACE "/display-seen-mail"
 #define MN_CONF_TOOLTIP_MAIL_SUMMARY \
@@ -94,7 +64,23 @@
 #define MN_CONF_ALWAYS_DISPLAY_ICON \
   MN_CONF_NAMESPACE "/always-display-icon"
 #define MN_CONF_CLICK_ACTION \
-  MN_CONF_NAMESPACE "/click-action"
+  MN_CONF_NAMESPACE "/click-action-2"
+#define MN_CONF_POPUPS_NAMESPACE \
+  MN_CONF_NAMESPACE "/popups"
+#define MN_CONF_POPUPS_ENABLED \
+  MN_CONF_POPUPS_NAMESPACE "/enabled"
+#define MN_CONF_POPUPS_POSITION \
+  MN_CONF_POPUPS_NAMESPACE "/position"
+#define MN_CONF_POPUPS_EXPIRATION_NAMESPACE \
+  MN_CONF_POPUPS_NAMESPACE "/expiration"
+#define MN_CONF_POPUPS_EXPIRATION_ENABLED \
+  MN_CONF_POPUPS_EXPIRATION_NAMESPACE "/enabled"
+#define MN_CONF_POPUPS_EXPIRATION_DELAY_NAMESPACE \
+  MN_CONF_POPUPS_EXPIRATION_NAMESPACE "/delay"
+#define MN_CONF_POPUPS_EXPIRATION_DELAY_MINUTES \
+  MN_CONF_POPUPS_EXPIRATION_DELAY_NAMESPACE "/minutes"
+#define MN_CONF_POPUPS_EXPIRATION_DELAY_SECONDS \
+  MN_CONF_POPUPS_EXPIRATION_DELAY_NAMESPACE "/seconds"
 
 /* obsolete keys */
 #define MN_CONF_OBSOLETE_MAILBOXES \
@@ -105,6 +91,8 @@
   "/desktop/gnome/url-handlers/mailto"
 #define MN_CONF_GNOME_MAIL_READER_COMMAND \
   MN_CONF_GNOME_MAIL_READER_NAMESPACE "/command"
+#define MN_CONF_GNOME_MAIL_READER_NEEDS_TERMINAL \
+  MN_CONF_GNOME_MAIL_READER_NAMESPACE "/needs_terminal"
 
 extern const char *mn_conf_dot_dir;
 
@@ -121,9 +109,6 @@ void		mn_conf_set_value	(const char	*key,
 
 void		mn_conf_link		(gpointer	object,
 					 ...);
-void		mn_conf_link_combo_box_to_string (GtkComboBox	*combo,
-						  int		string_column,
-						  const char	*key);
 void		mn_conf_link_radio_group_to_enum (GType		enum_type,
 						  const char	*key,
 						  ...);
@@ -137,12 +122,10 @@ unsigned int	mn_conf_notification_add_full	(const char		*key,
 						 GFreeFunc		destroy_notify);
 
 gboolean	mn_conf_has_command		(const char	*namespace);
-void		mn_conf_execute_command		(const char	*conf_key,
-						 gboolean	strip_format);
+void		mn_conf_execute_command		(const char	*conf_key);
+void		mn_conf_execute_mail_reader	(void);
 
-MNLockedGSource *mn_conf_timeout_add_gdk_locked	(const char	*minutes_key,
-						 const char	*seconds_key,
-						 GSourceFunc	function,
-						 gpointer	data);
+int		mn_conf_get_milliseconds (const char	*minutes_key,
+					  const char	*seconds_key);
 
 #endif /* _MN_CONF_H */
