@@ -1,5 +1,6 @@
-/* 
- * Copyright (C) 2004, 2005 Jean-Yves Lefort <jylefort@brutele.be>
+/*
+ * Mail Notification
+ * Copyright (C) 2003-2007 Jean-Yves Lefort <jylefort@brutele.be>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -11,9 +12,9 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include "config.h"
@@ -54,8 +55,25 @@ mn_message_mime_header_decode_text (const char *str)
 MNMessage *
 mn_message_new_from_mime_message (MNMailbox *mailbox,
 				  GMimeMessage *mime_message,
+				  const char *uri,
 				  MNMessageFlags flags,
 				  gboolean handle_status)
+{
+  return mn_message_new_from_mime_message_full(MN_TYPE_MESSAGE,
+					       mailbox,
+					       mime_message,
+					       uri,
+					       flags,
+					       handle_status);
+}
+
+MNMessage *
+mn_message_new_from_mime_message_full (GType type,
+				       MNMailbox *mailbox,
+				       GMimeMessage *mime_message,
+				       const char *uri,
+				       MNMessageFlags flags,
+				       gboolean handle_status)
 {
   MNMessage *message;
   const char *message_id;
@@ -65,9 +83,23 @@ mn_message_new_from_mime_message (MNMailbox *mailbox,
   char *decoded_from;
   char *decoded_subject;
 
+  g_return_val_if_fail(type != 0, NULL);
   g_return_val_if_fail(mailbox == NULL || MN_IS_MAILBOX(mailbox), NULL);
   g_return_val_if_fail(GMIME_IS_MESSAGE(mime_message), NULL);
 
+  if (handle_status)
+    {
+      const char *status;
+
+      status = g_mime_message_get_header(mime_message, "Status");
+      if (status && strchr(status, 'R'))
+	return NULL;		/* the message was read */
+      else if (status && strchr(status, 'O'))
+	flags &= ~MN_MESSAGE_NEW;
+      else
+	flags |= MN_MESSAGE_NEW;
+    }
+
   message_id = g_mime_message_get_message_id(mime_message);
   g_mime_message_get_date(mime_message, &sent_time, NULL);
   from = g_mime_message_get_sender(mime_message);
@@ -76,18 +108,15 @@ mn_message_new_from_mime_message (MNMailbox *mailbox,
   decoded_from = from ? mn_message_mime_header_decode_text(from) : NULL;
   decoded_subject = subject ? mn_message_mime_header_decode_text(subject) : NULL;
 
-  if (handle_status)
-    {
-      const char *status;
-
-      status = g_mime_message_get_header(mime_message, "Status");
-      if (status && strchr(status, 'O'))
-	flags &= ~MN_MESSAGE_NEW;
-      else
-	flags |= MN_MESSAGE_NEW;
-    }
-
-  message = mn_message_new(mailbox, NULL, sent_time, message_id, decoded_from, decoded_subject, flags);
+  message = g_object_new(type,
+			 MN_MESSAGE_PROP_MAILBOX(mailbox),
+			 MN_MESSAGE_PROP_SENT_TIME(sent_time),
+			 MN_MESSAGE_PROP_ID((char *) message_id),
+			 MN_MESSAGE_PROP_FROM(decoded_from),
+			 MN_MESSAGE_PROP_SUBJECT(decoded_subject),
+			 MN_MESSAGE_PROP_URI((char *) uri),
+			 MN_MESSAGE_PROP_FLAGS(flags),
+			 NULL);
 
   g_free(decoded_from);
   g_free(decoded_subject);
@@ -98,13 +127,31 @@ mn_message_new_from_mime_message (MNMailbox *mailbox,
 MNMessage *
 mn_message_new_from_mime_stream (MNMailbox *mailbox,
 				 GMimeStream *mime_stream,
+				 const char *uri,
 				 MNMessageFlags flags,
 				 gboolean handle_status)
+{
+  return mn_message_new_from_mime_stream_full(MN_TYPE_MESSAGE,
+					      mailbox,
+					      mime_stream,
+					      uri,
+					      flags,
+					      handle_status);
+}
+
+MNMessage *
+mn_message_new_from_mime_stream_full (GType type,
+				      MNMailbox *mailbox,
+				      GMimeStream *mime_stream,
+				      const char *uri,
+				      MNMessageFlags flags,
+				      gboolean handle_status)
 {
   GMimeParser *parser;
   GMimeMessage *mime_message;
   MNMessage *message;
 
+  g_return_val_if_fail(type != 0, NULL);
   g_return_val_if_fail(mailbox == NULL || MN_IS_MAILBOX(mailbox), NULL);
   g_return_val_if_fail(GMIME_IS_STREAM(mime_stream), NULL);
 
@@ -114,7 +161,7 @@ mn_message_new_from_mime_stream (MNMailbox *mailbox,
 
   if (mime_message)
     {
-      message = mn_message_new_from_mime_message(mailbox, mime_message, flags, handle_status);
+      message = mn_message_new_from_mime_message_full(type, mailbox, mime_message, uri, flags, handle_status);
       g_object_unref(mime_message);
     }
   else
@@ -128,10 +175,25 @@ mn_message_new_from_uri (MNMailbox *mailbox,
 			 GnomeVFSURI *uri,
 			 MNMessageFlags flags,
 			 gboolean handle_status)
+{
+  return mn_message_new_from_uri_full(MN_TYPE_MESSAGE,
+				      mailbox,
+				      uri,
+				      flags,
+				      handle_status);
+}
+
+MNMessage *
+mn_message_new_from_uri_full (GType type,
+			      MNMailbox *mailbox,
+			      GnomeVFSURI *uri,
+			      MNMessageFlags flags,
+			      gboolean handle_status)
 {
   GnomeVFSResult result;
   GnomeVFSHandle *handle;
 
+  g_return_val_if_fail(type != 0, NULL);
   g_return_val_if_fail(mailbox == NULL || MN_IS_MAILBOX(mailbox), NULL);
   g_return_val_if_fail(uri != NULL, NULL);
 
@@ -144,8 +206,13 @@ mn_message_new_from_uri (MNMailbox *mailbox,
       if (stream)
 	{
 	  MNMessage *message;
+	  char *text_uri;
 
-	  message = mn_message_new_from_mime_stream(mailbox, stream, flags, handle_status);
+	  text_uri = gnome_vfs_uri_to_string(uri, GNOME_VFS_URI_HIDE_NONE);
+
+	  message = mn_message_new_from_mime_stream_full(type, mailbox, stream, text_uri, flags, handle_status);
+
+	  g_free(text_uri);
 	  g_object_unref(stream);
 
 	  result = gnome_vfs_close(handle);
@@ -175,7 +242,7 @@ mn_message_new_from_buffer (MNMailbox *mailbox,
   g_return_val_if_fail(buffer != NULL, NULL);
 
   stream = g_mime_stream_mem_new_with_buffer(buffer, len);
-  message = mn_message_new_from_mime_stream(mailbox, stream, flags, handle_status);
+  message = mn_message_new_from_mime_stream(mailbox, stream, NULL, flags, handle_status);
   g_object_unref(stream);
 
   return message;
