@@ -1,5 +1,6 @@
-/* 
- * Copyright (C) 2003-2006 Jean-Yves Lefort <jylefort@brutele.be>
+/*
+ * Mail Notification
+ * Copyright (C) 2003-2007 Jean-Yves Lefort <jylefort@brutele.be>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -11,9 +12,9 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #ifndef _MN_UTIL_H
@@ -57,14 +58,13 @@ GSList		*mn_g_object_slist_ref		(GSList		*list);
 GSList		*mn_g_object_slist_copy		(GSList		*list);
 void		mn_g_object_slist_free		(GSList		*list);
 void		mn_g_object_slist_clear		(GSList		**list);
-GSList		*mn_g_object_slist_delete_link	(GSList		*list,
-						 GSList		*link_);
 
 void		mn_g_queue_free_deep_custom	(GQueue		*queue,
 						 GFunc		element_free_func,
 						 gpointer	user_data);
 
 gboolean	mn_str_isnumeric		(const char	*str);
+gboolean	mn_str_ishex			(const char	*str);
 char		*mn_strstr_span			(const char	*big,
 						 const char	*little);
 
@@ -95,6 +95,9 @@ gboolean	mn_parse_gnome_copied_files	(const char	*gnome_copied_files,
 
 void		mn_display_help			(GtkWindow	*parent,
 						 const char	*link_id);
+void		mn_open_link			(GtkWindow	*parent,
+						 const char	*url);
+
 void		mn_thread_create		(GThreadFunc	func,
 						 gpointer	data);
 
@@ -109,6 +112,10 @@ void		mn_error_dialog			(GtkWindow	*parent,
 						 const char	*primary,
 						 const char	*format,
 						 ...) G_GNUC_PRINTF(3, 4);
+void		mn_error_dialog_with_markup	(GtkWindow	*parent,
+						 const char	*primary,
+						 const char	*format,
+						 ...) G_GNUC_PRINTF(3, 4);
 void		mn_invalid_uri_dialog		(GtkWindow	*parent,
 						 const char	*primary,
 						 const char	*invalid_uri);
@@ -119,13 +126,21 @@ void		mn_fatal_error_dialog		(GtkWindow	*parent,
 						 const char	*format,
 						 ...) G_GNUC_PRINTF(2, 3) G_GNUC_NORETURN;
 
+typedef enum
+{
+  MN_DIALOG_BLOCKING	= 1 << 0,
+  MN_DIALOG_MARKUP	= 1 << 1
+} MNDialogFlags;
+
 GtkWidget	*mn_alert_dialog_new		(GtkWindow	*parent,
 						 GtkMessageType	type,
+						 MNDialogFlags	flags,
 						 const char	*primary,
 						 const char	*secondary);
 
 time_t		mn_time				(void);
 
+void		mn_g_object_null_unref		(gpointer	object);
 gpointer	mn_g_object_connect		(gpointer	object,
 						 gpointer	instance,
 						 const char	*signal_spec,
@@ -154,4 +169,20 @@ void		mn_gdk_threads_leave		(void);
 void		mn_g_static_mutex_lock		(GStaticMutex *mutex);
 void		mn_g_static_mutex_unlock	(GStaticMutex *mutex);
 
+void		mn_execute_command		(const char	*command);
+void		mn_execute_command_in_terminal	(const char	*command);
+
+char		*mn_shell_quote_safe		(const char	*unquoted_string);
+
+GtkWidget	*mn_hig_section_new		(const char	*title,
+						 GtkWidget	**label,
+						 GtkWidget	**alignment);
+GtkWidget	*mn_hig_section_new_with_box	(const char	*title,
+						 GtkWidget	**label,
+						 GtkWidget	**vbox);
+
+char		*mn_g_value_to_string		(const GValue	*value);
+gboolean	mn_g_value_from_string		(GValue		*value,
+						 const char	*str);
+
 #endif /* _MN_UTIL_H */
